<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hr">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../about.ui" line="14"/>
        <source>About</source>
        <translation>Informacije</translation>
    </message>
    <message>
        <location filename="../about.ui" line="34"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;LXQt Archiver&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;LXQt Arhivist&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../about.ui" line="57"/>
        <source>A simple and desktop-agnostic Qt file archiver</source>
        <translation>Jednostavan Qt program za arhiviranje datoteka</translation>
    </message>
    <message>
        <location filename="../about.ui" line="67"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;https://github.com/lxqt/lxqt-archiver&quot;&gt;https://github.com/lxqt/lxqt-archiver&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;
</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;https://github.com/lxqt/lxqt-archiver&quot;&gt;https://github.com/lxqt/lxqt-archiver&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;
</translation>
    </message>
    <message>
        <location filename="../about.ui" line="91"/>
        <source>Authors</source>
        <translation>Autori</translation>
    </message>
    <message>
        <location filename="../about.ui" line="100"/>
        <source>Programming:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;

LXQt Archiver is derived from the following programs:
* Engrampa of MATE desktop
* File Roller of Gnome desktop
</source>
        <translation>Programiranje:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;

Program LXQt Arhivist izveden je iz:
* Engrampa, MATE radna površina
* File Roller, Gnome radna površina
</translation>
    </message>
    <message>
        <location filename="../about.ui" line="117"/>
        <source>License</source>
        <translation>Licenca</translation>
    </message>
    <message>
        <location filename="../about.ui" line="126"/>
        <source>LXQt Archiver

Copyright (C) 2020 the LXQt Team

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.</source>
        <translation>LXQt Arhivist

Copyright (C) 2020. LXQt tim

Ovaj program je slobodan softver: može se redistribuirati i/ili mijenjati
pod uvjetima GNU opće javne licence, koju je objavila zaklada
Free Software Foundation, u 2. verziji licence ili (po izboru) bilo koje
novije verzije.

Ovaj se program distribuira u nadi da će biti koristan, ali BEZ
IKAKVOG JAMSTVA; čak i bez podrazumijevanog jamstva za
PRODAJU ili PRIKLADNOST ZA ODREĐENU SVRHU.
Pogledaj GNU Opću javnu licencu za pojedinosti.

GNU opća javna licenca je standardno pridodana ovom programu.
Ako nije, kontaktiraj zakladu Free Software Foundation,
Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.</translation>
    </message>
</context>
<context>
    <name>Archiver</name>
    <message>
        <location filename="../archiver.cpp" line="66"/>
        <source>Archive type not supported.</source>
        <translation>Vrsta arhive nije podržana.</translation>
    </message>
    <message>
        <location filename="../archiver.cpp" line="310"/>
        <source>*%1 files (*%1)</source>
        <translation>*%1 datoteke (*%1)</translation>
    </message>
    <message>
        <location filename="../archiver.cpp" line="314"/>
        <source>All supported formats</source>
        <translation>Svi podržani formati</translation>
    </message>
</context>
<context>
    <name>ArchiverError</name>
    <message>
        <location filename="../archivererror.cpp" line="25"/>
        <source>Failed to execute the command.</source>
        <translation>Neuspjelo izvršavanje naredbe.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="28"/>
        <source>Command is not found.</source>
        <translation>Naredba nije pronađena.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="31"/>
        <source>The command exited abnormally.</source>
        <translation>Naredba je nenadano prekinuta.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="34"/>
        <source>Password is required.</source>
        <translation>Potrebna je lozinka.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="37"/>
        <source>Missing volume.</source>
        <translation>Nedostaje jedan dio.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="40"/>
        <source>Bad charset.</source>
        <translation>Neispravan skup znakova.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="43"/>
        <source>Unsupported file format.</source>
        <translation>Nepodržan datotečni format.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="46"/>
        <source>Unknown errors happened.</source>
        <translation>Dogodile su se nepoznate greške.</translation>
    </message>
</context>
<context>
    <name>CreateArchiveExtraWidget</name>
    <message>
        <location filename="../create.ui" line="26"/>
        <source> MiB</source>
        <translation> MiB</translation>
    </message>
    <message>
        <location filename="../create.ui" line="36"/>
        <source>Split into volumes of</source>
        <translation>Rastavi u dijelove od</translation>
    </message>
    <message>
        <location filename="../create.ui" line="43"/>
        <source>Password:</source>
        <translation>Lozinka:</translation>
    </message>
    <message>
        <location filename="../create.ui" line="50"/>
        <source>Encrypt the file list too</source>
        <translation>Šifriraj i popis datoteka</translation>
    </message>
</context>
<context>
    <name>CreateFileDialog</name>
    <message>
        <location filename="../createfiledialog.cpp" line="12"/>
        <source>Create Archive</source>
        <translation>Stvori arhivu</translation>
    </message>
    <message>
        <location filename="../createfiledialog.cpp" line="14"/>
        <source>All files (*)</source>
        <translation>Sve datoteke (*)</translation>
    </message>
</context>
<context>
    <name>ExtractArchiveExtraWidget</name>
    <message>
        <location filename="../extract.ui" line="23"/>
        <source>Extract</source>
        <translation>Raspakiraj</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="29"/>
        <source>E&amp;xtract all files</source>
        <translation>Raspa&amp;kiraj sve datoteke</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="36"/>
        <source>Ex&amp;tract selected files</source>
        <translation>Ra&amp;spakiraj odabrane datoteke</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="59"/>
        <source>Actions</source>
        <translation>Radnje</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="65"/>
        <source>Re-create folders</source>
        <translation>Ponovo izradi mape</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="75"/>
        <source>Overwrite existing files</source>
        <translation>Prepiši postojeće mape</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="82"/>
        <source>Do not extract older files</source>
        <translation>Nemoj raspakirati starije datoteke</translation>
    </message>
</context>
<context>
    <name>ExtractFileDialog</name>
    <message>
        <location filename="../extractfiledialog.cpp" line="11"/>
        <source>Extract</source>
        <translation>Raspakiraj</translation>
    </message>
    <message>
        <location filename="../extractfiledialog.cpp" line="13"/>
        <source>All files (*)</source>
        <translation>Sve datoteke (*)</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="328"/>
        <source>File Archiver</source>
        <translation>Arhiviranje datoteka</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="62"/>
        <source>Filter Files...</source>
        <translation>Filtriraj datoteke …</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="86"/>
        <source>&amp;File</source>
        <translation>&amp;Datoteka</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="101"/>
        <source>&amp;Edit</source>
        <translation>&amp;Uredi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="120"/>
        <source>&amp;View</source>
        <translation>Prika&amp;z</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="124"/>
        <source>&amp;Icon Size</source>
        <translation>&amp;Veličine ikona</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="152"/>
        <source>&amp;Help</source>
        <translation>&amp;Pomoć</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="163"/>
        <source>Main Toolbar</source>
        <translation>Glavna traka alata</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="191"/>
        <source>&amp;About</source>
        <translation>&amp;Informacije</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="200"/>
        <source>&amp;New</source>
        <translation>&amp;Nova</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="203"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="212"/>
        <source>&amp;Open</source>
        <translation>&amp;Otvori</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="215"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="223"/>
        <source>Save &amp;As</source>
        <translation>Spremi k&amp;ao</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="226"/>
        <source>Ctrl+Shift+S</source>
        <translation>Ctrl+Shift+S</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="231"/>
        <source>&amp;Extract</source>
        <translation>Otpa&amp;kiraj</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="236"/>
        <source>&amp;Test</source>
        <translation>&amp;Testiraj</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="239"/>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="251"/>
        <source>&amp;Properties</source>
        <translation>&amp;Svojstva</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="254"/>
        <source>Alt+Return</source>
        <translation>Alt+Return</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="263"/>
        <source>&amp;Close</source>
        <translation>&amp;Zatvori</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="266"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="274"/>
        <source>Cu&amp;t</source>
        <translation>Iz&amp;reži</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="277"/>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="285"/>
        <source>&amp;Copy</source>
        <translation>&amp;Kopiraj</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="288"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="296"/>
        <source>&amp;Paste</source>
        <translation>&amp;Umetni</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="299"/>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="307"/>
        <source>&amp;Rename</source>
        <translation>Prei&amp;menuj</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="310"/>
        <source>F2</source>
        <translation>F2</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="319"/>
        <source>&amp;Delete</source>
        <translation>&amp;Izbriši</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="322"/>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="331"/>
        <source>&amp;Select All</source>
        <translation>Oda&amp;beri sve</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="334"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="342"/>
        <source>&amp;Find</source>
        <translation>Pro&amp;nađi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="345"/>
        <location filename="../mainwindow.ui" line="464"/>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="350"/>
        <source>&amp;Add Files</source>
        <translation>Dod&amp;aj datoteke</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="355"/>
        <source>Add F&amp;older</source>
        <translation>Dodaj &amp;mapu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="364"/>
        <source>Pass&amp;word</source>
        <translation>Lo&amp;zinka</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="375"/>
        <source>&amp;Toolbar</source>
        <translation>&amp;Traka alata</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="386"/>
        <source>&amp;Statusbar</source>
        <translation>Traka &amp;stanja</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="397"/>
        <source>&amp;Directory Tree</source>
        <translation>Sta&amp;blo direktorija</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="408"/>
        <source>S&amp;how as Folder</source>
        <translation>Pri&amp;kaži kao mapu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="411"/>
        <source>Ctrl+Shift+D</source>
        <translation>Ctrl+Shift+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="419"/>
        <source>Show &amp;All Files</source>
        <translation>Prikaži s&amp;ve datoteke</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="422"/>
        <source>Ctrl+Shift+A</source>
        <translation>Ctrl+Shift+V</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="431"/>
        <source>St&amp;op</source>
        <translation>&amp;Zaustavi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="434"/>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="443"/>
        <source>&amp;Reload</source>
        <translation>&amp;Učitaj ponovo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="446"/>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="451"/>
        <source>Filename &amp;Encoding</source>
        <translation>&amp;Kodiranje imena datoteke</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="456"/>
        <source>&amp;View Selected Items</source>
        <translation>Prika&amp;z odabranih stavki</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="461"/>
        <source>&amp;Filter</source>
        <translation>&amp;Filtar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="472"/>
        <source>&amp;Expand</source>
        <translation>Ras&amp;klopi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="475"/>
        <source>Ctrl+Shift+E</source>
        <translation>Ctrl+Shift+K</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="486"/>
        <source>Ctrl+Shift+C</source>
        <translation>Ctrl+Shift+L</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="483"/>
        <source>&amp;Collapse</source>
        <translation>Sk&amp;lopi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="494"/>
        <source>16 px</source>
        <translation>16 px</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="502"/>
        <source>24 px</source>
        <translation>24 px</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="510"/>
        <source>32 px</source>
        <translation>32 px</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="518"/>
        <source>48 px</source>
        <translation>48 px</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="373"/>
        <location filename="../mainwindow.cpp" line="403"/>
        <location filename="../mainwindow.cpp" line="437"/>
        <source>All files (*)</source>
        <translation>Sve datoteke (*)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="408"/>
        <location filename="../mainwindow.cpp" line="442"/>
        <source>Add only if &amp;newer</source>
        <translation>Dodaj samo, ako je &amp;novija</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="467"/>
        <source>Confirm</source>
        <translation>Potvrdi</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="467"/>
        <source>Are you sure you want to delete selected files?</source>
        <translation>Stvarno želiš izbrisati odabrane datoteke?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="769"/>
        <source>Version: %1</source>
        <translation>Verzija: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="878"/>
        <source>%p %</source>
        <translation>%p %</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="982"/>
        <source>Success</source>
        <translation>Uspjeh</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="982"/>
        <source>No errors have been found.</source>
        <translation>Nema grešaka.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="960"/>
        <location filename="../mainwindow.cpp" line="1020"/>
        <source>Error</source>
        <translation>Greška</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="371"/>
        <source>Open</source>
        <translation>Otvori</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="401"/>
        <source>Add Files</source>
        <translation>Dodaj datoteke</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="434"/>
        <source>Add Folder</source>
        <translation>Dodaj mapu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1050"/>
        <source>N/A</source>
        <translation>--</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1054"/>
        <source>Uncompressed Size:</source>
        <translation>Veličina u nekromprimiranom stanju:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1056"/>
        <source>Compression Ratio:</source>
        <translation>Omjer komprimiranja:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1075"/>
        <source>Link to</source>
        <translation>Poveži na</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1114"/>
        <source>File name</source>
        <translation>Ime datoteke</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1115"/>
        <source>File Type</source>
        <translation>Vrsta datoteke</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1116"/>
        <source>File Size</source>
        <translation>Veličina datoteke</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1117"/>
        <source>Modified</source>
        <translation>Promijenjeno</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1118"/>
        <source>Encrypted</source>
        <translation>Šifrirano</translation>
    </message>
    <message numerus="yes">
        <location filename="../mainwindow.cpp" line="1145"/>
        <source>%n file(s)</source>
        <translation>
            <numerusform>%n datoteka</numerusform>
            <numerusform>%n datoteke</numerusform>
            <numerusform>%n datoteka</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <location filename="../passworddialog.ui" line="14"/>
        <location filename="../passworddialog.cpp" line="60"/>
        <source>Password</source>
        <translation>Lozinka</translation>
    </message>
    <message>
        <location filename="../passworddialog.ui" line="20"/>
        <source>Encrypt the file list</source>
        <translation>Šifriraj popis datoteka</translation>
    </message>
    <message>
        <location filename="../passworddialog.ui" line="34"/>
        <source>Show password</source>
        <translation>Prikaži lozinku</translation>
    </message>
    <message>
        <location filename="../passworddialog.ui" line="48"/>
        <location filename="../passworddialog.cpp" line="60"/>
        <source>Password:</source>
        <translation>Lozinka:</translation>
    </message>
    <message>
        <location filename="../passworddialog.ui" line="61"/>
        <source>&lt;i&gt;&lt;b&gt;Note:&lt;/b&gt; the password will be used to encrypt files you add to the current archive, and to decrypt files you extract from the current archive. When the archive is closed the password will be deleted.&lt;/i&gt;</source>
        <translation>&lt;i&gt;&lt;b&gt;Napomena:&lt;/b&gt; lozinka će se koristiti za šifriranje datoteka koje se dodaju u trenutačnu arhivu i za dešifriranje datoteka koje se raspakiraju iz trenutačne arhive. Kad se arhiva zatvori, lozinka će se izbrisati.&lt;/i&gt;</translation>
    </message>
</context>
<context>
    <name>ProgressDialog</name>
    <message>
        <location filename="../progressdialog.ui" line="14"/>
        <source>Progress</source>
        <translation>Napredak</translation>
    </message>
    <message>
        <location filename="../progressdialog.cpp" line="16"/>
        <source>%p %</source>
        <translation>%p %</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="248"/>
        <location filename="../main.cpp" line="300"/>
        <source>Error</source>
        <translation>Greška</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="6"/>
        <source>7-Zip (.7z)</source>
        <translation>7-Zip (.7z)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="7"/>
        <source>Tar compressed with 7z (.tar.7z)</source>
        <translation>Tar komprimirano sa 7z (.tar.7z)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="8"/>
        <source>Ace (.ace)</source>
        <translation>Ace (.ace)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="9"/>
        <source>Ar (.a)</source>
        <translation>Ar (.a)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="10"/>
        <source>Ar (.ar)</source>
        <translation>Ar (.ar)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="11"/>
        <source>Arj (.arj)</source>
        <translation>Arj (.arj)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="12"/>
        <source>Tar compressed with bzip2 (.tar.bz2)</source>
        <translation>Tar komprimirano s bzip2 (.tar.bz2)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="13"/>
        <source>Tar compressed with bzip (.tar.bz)</source>
        <translation>Tar komprimirano s bzip (.tar.bz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="14"/>
        <source>Cabinet (.cab)</source>
        <translation>Cabinet (.cab)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="15"/>
        <source>Rar Archived Comic Book (.cbr)</source>
        <translation>Rar arhiviran strip (.cbr)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="16"/>
        <source>Zip Archived Comic Book (.cbz)</source>
        <translation>Zip arhiviran strip (.cbz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="17"/>
        <source>Tar compressed with gzip (.tar.gz)</source>
        <translation>Tar komprimirano s gzip (.tar.gz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="18"/>
        <source>Ear (.ear)</source>
        <translation>Ear (.ear)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="19"/>
        <source>Self-extracting zip (.exe)</source>
        <translation>Samoraspakirajući zip (.exe)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="20"/>
        <source>Jar (.jar)</source>
        <translation>Jar (.jar)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="21"/>
        <source>Lha (.lzh)</source>
        <translation>Lha (.lzh)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="22"/>
        <source>Lrzip (.lrz)</source>
        <translation>Lrzip (.lrz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="23"/>
        <source>Tar compressed with lrzip (.tar.lrz)</source>
        <translation>Tar komprimirano s lrzip (.tar.lrz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="24"/>
        <source>Tar compressed with lzip (.tar.lz)</source>
        <translation>Tar komprimirano s lzip (.tar.lz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="25"/>
        <source>Tar compressed with lzma (.tar.lzma)</source>
        <translation>Tar komprimirano s lzma (.tar.lzma)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="26"/>
        <source>Tar compressed with lzop (.tar.lzo)</source>
        <translation>Tar komprimirano s lzop (.tar.lzo)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="27"/>
        <source>Windows Imaging Format (.wim)</source>
        <translation>Windows Imaging Format (.wim)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="28"/>
        <source>Rar (.rar)</source>
        <translation>Rar (.rar)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="29"/>
        <source>Tar uncompressed (.tar)</source>
        <translation>Tar nekomprimirano (.tar)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="30"/>
        <source>Tar compressed with compress (.tar.Z)</source>
        <translation>Tar komprimirano s kompresijom (.tar.Z)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="31"/>
        <source>War (.war)</source>
        <translation>War (.war)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="32"/>
        <source>Xz (.xz)</source>
        <translation>Xz (.xz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="33"/>
        <source>Tar compressed with xz (.tar.xz)</source>
        <translation>Tar komprimirano s xz (.tar.xz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="34"/>
        <source>Tar compressed with zstd (.tar.zst)</source>
        <translation>Tar komprimirano sa zstd (.tar.zst)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="35"/>
        <source>Zoo (.zoo)</source>
        <translation>Zoo (.zoo)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="36"/>
        <source>Zip (.zip)</source>
        <translation>Zip (.zip)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="39"/>
        <location filename="../corestrs.h" line="46"/>
        <location filename="../corestrs.h" line="62"/>
        <location filename="../main.cpp" line="240"/>
        <source>Adding file: </source>
        <translation>Dodavanje datoteke: </translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="40"/>
        <location filename="../corestrs.h" line="49"/>
        <location filename="../corestrs.h" line="64"/>
        <location filename="../main.cpp" line="282"/>
        <source>Extracting file: </source>
        <translation>Raspakiravanje datoteke: </translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="43"/>
        <source>%d %B %Y, %H:%M</source>
        <translation>%d. %B %Y., %H:%M</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="47"/>
        <location filename="../corestrs.h" line="63"/>
        <source>Removing file: </source>
        <translation>Uklanjanje datoteke: </translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="48"/>
        <source>Deleting files from archive</source>
        <translation>Brisanje datoteka iz arhive</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="50"/>
        <source>Recompressing archive</source>
        <translation>Ponovno komprimiranje arhive</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="51"/>
        <source>Decompressing archive</source>
        <translation>Otpakiravanje arhive</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="54"/>
        <source>File not found.</source>
        <translation>Datoteka nije pronađena.</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="55"/>
        <source>Archive type not supported.</source>
        <translation>Vrsta arhive nije podržana.</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="56"/>
        <source>Archive not found</source>
        <translation>Arhiva nije pronađena</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="57"/>
        <source>You don&apos;t have the right permissions.</source>
        <translation>Nemaš ispravne dozvole.</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="58"/>
        <source>This archive type cannot be modified</source>
        <translation>Ova vrsta arhive se ne može promijeniti</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="59"/>
        <source>You can&apos;t add an archive to itself.</source>
        <translation>Ne možeš dodati arhivu samu sebi.</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="65"/>
        <source>Could not find the volume: %s</source>
        <translation>Nije bilo moguće pronaći jedinicu memorije: %s</translation>
    </message>
</context>
</TS>
